@@ -1,9 +1,9 @@
 package ColorTheme::Text::ANSITable::Standard::Gradation;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-10-05'; # DATE
+our $DATE = '2021-02-19'; # DATE
 our $DIST = 'Text-ANSITable'; # DIST
-our $VERSION = '0.601'; # VERSION
+our $VERSION = '0.602'; # VERSION
 
 use parent 'ColorThemeBase::Static::FromStructColors';
 
@@ -92,7 +92,7 @@ ColorTheme::Text::ANSITable::Standard::Gradation - Gradation border (for termina
 
 =head1 VERSION
 
-This document describes version 0.601 of ColorTheme::Text::ANSITable::Standard::Gradation (from Perl distribution Text-ANSITable), released on 2020-10-05.
+This document describes version 0.602 of ColorTheme::Text::ANSITable::Standard::Gradation (from Perl distribution Text-ANSITable), released on 2021-02-19.
 
 =head1 DESCRIPTION
 
@@ -111,7 +111,7 @@ Source repository is at L<https://github.com/perlancar/perl-Text-ANSITable>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-ANSITable>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Text-ANSITable/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -123,7 +123,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
