@@ -1,7 +1,7 @@
 package Text::ANSITable::StyleSet::AltRow;
 
-our $DATE = '2020-10-05'; # DATE
-our $VERSION = '0.601'; # VERSION
+our $DATE = '2021-02-19'; # DATE
+our $VERSION = '0.602'; # VERSION
 
 use 5.010;
 use Moo;
@@ -56,7 +56,7 @@ Text::ANSITable::StyleSet::AltRow - Set different foreground and/or background c
 
 =head1 VERSION
 
-This document describes version 0.601 of Text::ANSITable::StyleSet::AltRow (from Perl distribution Text-ANSITable), released on 2020-10-05.
+This document describes version 0.602 of Text::ANSITable::StyleSet::AltRow (from Perl distribution Text-ANSITable), released on 2021-02-19.
 
 =for Pod::Coverage ^(summary|apply)$
 
@@ -80,7 +80,7 @@ Source repository is at L<https://github.com/perlancar/perl-Text-ANSITable>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-ANSITable>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Text-ANSITable/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -92,7 +92,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
